@@ -8,6 +8,10 @@
 
 #include <QtSensors/QAccelerometer>
 
+#ifdef Q_WS_MAEMO_5
+#include <QtDBus/QtDBus>
+#endif
+
 // Neccessary for Qt Mobility API usage
 QTM_USE_NAMESPACE
 
@@ -34,10 +38,16 @@ public:
 public slots:
 	void showAbout();
 	void showSettings();
+#ifdef Q_WS_MAEMO_5
+	void screenChange(const QDBusMessage &message);
+#endif
 
 private:
 	QAccelerometer *accelerometer;
 	AMeterWidget *awidget;
+#ifdef Q_WS_MAEMO_5
+	QDBusInterface *dBusInterface;
+#endif
 };
 
 #endif // MAINWINDOW_H
